elephant.spike\_train\_dissimilarity.van\_rossum\_distance
==========================================================

.. currentmodule:: elephant.spike_train_dissimilarity

.. autofunction:: van_rossum_distance